import { 
  select, 
  csv,
	scaleBand,
  scaleLinear,
	max,
	axisBottom,
	axisLeft } from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  
  const xValue = d => d.country;
  const yValue = d => d.immigrants_prop;
  const margin = {top: 20, right: 20, bottom: 20, left: 40};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleBand()
  	.domain(data.map(xValue))
  	.range([0, innerWidth])
  	.padding(0.1);
  
  const yScale = scaleLinear()
  	.domain([0, max(data, d => d.immigrants_prop)])
  	.range([0, innerHeight].reverse());
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  g.append('g').call(axisBottom(xScale))
  	.attr('transform', `translate(0, ${innerHeight})`);
  g.append('g').call(axisLeft(yScale))
  
  g.selectAll('rect').data(data)
  	.enter().append('rect')
  	.attr('x', d => xScale(xValue(d)))
  	.attr('y', d => yScale(yValue(d)))
  	.attr('width', d => xScale.bandwidth())
  	.attr('height', d => innerHeight - yScale(yValue(d)));
}

csv('data.csv').then(data => {
  data.forEach(d => {
  	d.immigrants_prop = +d.immigrants_prop;
  })
	render(data)
})






















